@@ -32,7 +32,7 @@ A script to get the vlan tag info from switches supporting the Q-BRIDGE-MIB.
 
 use blib;
 use Net::SNMP qw(:debug :snmp);
-use Net::SNMP::Mixin qw/mixer init_mixins/;
+use Net::SNMP::Mixin;
 use List::Util;
 use Getopt::Std;
 
@@ -76,7 +76,10 @@ foreach my $agent ( sort @agents ) {
   push @sessions, $session;
 
 }
-snmp_dispatcher() if $Net::SNMP::NONBLOCKING;
+snmp_dispatcher();
+
+# check for init errors
+$_->init_ok foreach @sessions;
 
 # remove sessions with error from the sessions list
 @sessions = grep { warn $_->error if $_->error; not $_->error } @sessions;
@@ -164,7 +167,7 @@ Karl Gaissmaier, karl.gaissmaier (at) uni-ulm.de
 
 =head1 COPYRIGHT
 
-Copyright (C) 2008 by Karl Gaissmaier
+Copyright (C) 2008-2016 by Karl Gaissmaier
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
